@@ -40,7 +40,7 @@ class Check:
     def _check_github(self):
         if self._tokens.github:
             try:
-                if self._github.get_user().login:
+                if self._github.get_organization():
                     return "ok"
                 self._invalid_or_missing_tokens.append("github")
                 return "invalid_token"
