@@ -16,6 +16,8 @@ from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.qainit_handler import QainitHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
+from suite_py.lib.handler.drone_handler import DroneHandler
+from suite_py.commands.login import Login
 
 
 class QA:
@@ -28,8 +30,13 @@ class QA:
         self._git = GitHandler(project, config)
         self._qainit = QainitHandler(project, config, tokens)
         self._youtrack = YoutrackHandler(config, tokens)
+        self._drone = DroneHandler(config, tokens)
 
     def run(self):
+        if not self._qainit.user_info():
+            logger.warning("You're not logged in.")
+            Login(self._config).run()
+
         if self._action == "list":
             self._list()
         elif self._action == "create":
@@ -140,6 +147,18 @@ class QA:
         jsonify = self._flags["json"]
 
         r = self._qainit.describe(qa_hash)
+
+        issues = self._check_instance_issues(r)
+        if issues:
+            msg = "an issue" if len(issues) == 1 else f"{len(issues)} issues"
+            logger.warning(f"⚠️  suite-py diagnostic tool found {msg}:")
+            for i in issues:
+                logger.warning(i)
+            logger.warning(
+                "If the problem persist write a detailed message on #team-devops"
+            )
+            sys.exit(-1)
+
         if jsonify:
             print(json.dumps(r, sort_keys=True, indent=2))
         else:
@@ -261,3 +280,66 @@ class QA:
 
     def _toggle_maintenance(self):
         self._qainit.maintenance()
+
+    def _check_instance_issues(self, response):
+        issues = []
+
+        if not response["list"]:
+            issues.append("QA not found")
+
+        # Check if instance status is still pending
+        if response["list"] and response["list"]["status"] in ["creating", "updating"]:
+            # 1. Microservices list is empty?
+            if len(response["list"]["resources"]) == 0:
+                issues.append("Microservices list is empty, please be patient.")
+
+            # 2. Check every resource
+            for resource in self._filter_list(
+                "status", ["creating", "updating"], response["list"]["resources"]
+            ):
+                issues += self._check_resource_issues(resource)
+
+        return issues
+
+    def _check_resource_issues(self, resource):
+        issues = []
+
+        build = self._drone.get_repo_build(resource["name"], resource["promoted_build"])
+
+        if "stages" not in build:
+            issues.append("Suite-py is unable to locate drone build.")
+            return issues
+
+        qainit_step = self._filter_list("name", ["qainit-it"], build["stages"])[0]
+        # Check if build is succeded
+        if build["status"] == "success" or qainit_step["status"] == "error":
+            issues.append(
+                f"Something between Drone and Qainit went wrong, did you try to restart the build? {self._drone.get_repo_build_url(resource['name'], resource['promoted_build'])}"
+            )
+
+        # Check if build is killed
+        elif build["status"] == "killed":
+            issues.append(
+                f"Seems someone killed the build, did you try to restart the build? {self._drone.get_repo_build_url(resource['name'], resource['promoted_build'])}"
+            )
+
+        # Check if build is failed
+        elif build["status"] == "failure":
+            build_pipeline = self._filter_list("name", ["build_qa"], build["stages"])[0]
+            if build_pipeline and build_pipeline["status"] == "failed":
+                issues.append(
+                    f"Something went wrong during microservice build step, check the logs {self._drone.get_build_and_pipeline_url(resource['name'], resource['promoted_build'], build_pipeline['number'])}"
+                )
+
+            deploy_pipeline = self._filter_list(
+                "name", ["deploy-it-qa"], build["stages"]
+            )[0]
+            if deploy_pipeline and deploy_pipeline["status"] == "failed":
+                issues.append(
+                    f"Something went wront during microservice deploy step, check the logs {self._drone.get_build_and_pipeline_url(resource['name'], resource['promoted_build'], deploy_pipeline['number'])}"
+                )
+
+        return issues
+
+    def _filter_list(self, search_key, in_list, search_list):
+        return list(filter(lambda l: l[search_key] in in_list, search_list))
